import 'dart:convert';

import 'package:flutter/material.dart';

import '../api/api.dart';
import '../log/log.dart';
import '../screen_loading.dart';
import '../types/tag.dart';

class AddTagDialog extends StatefulWidget {
  const AddTagDialog({Key? key, required this.movieId}) : super(key: key);
  final int movieId;

  @override
  State<AddTagDialog> createState() => _AddTagDialogState();
}

class _AddTagDialogState extends State<AddTagDialog> {
  late Future<List<Tag>> tags = loadAllTags();

  Future<List<Tag>> loadAllTags() async {
    final data = await API.query("tags", "getAllTags", {});

    final d = (jsonDecode(data) ?? []) as List<dynamic>;
    final tags = d.map((e) => Tag.fromJson(e)).toList(growable: false);
    return tags;
  }

  Future<void> addTagToVideo(int tagId) async {
    final data = await API
        .query("tags", "addTag", {'TagId': tagId, 'MovieId': widget.movieId});

    final d = jsonDecode(data);
    if (d["result"] != "success") {
      Log.w("couldn't add actor to video");
    }
  }

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
        scrollable: true,
        title: Text("Add Tag"),
        content: FutureBuilder(
          future: tags,
          builder: (context, snapshot) {
            if (snapshot.hasError) {
              return Text("Error");
            } else if (snapshot.hasData) {
              final data = snapshot.data! as List<Tag>;
              return Column(
                mainAxisSize: MainAxisSize.min,
                children: data
                    .map(
                      (e) => ListTile(
                        title: Text(e.tagName),
                        onTap: () async {
                          await addTagToVideo(e.tagId);
                          Navigator.pop(context, e);
                        },
                      ),
                    )
                    .toList(),
              );
            } else {
              return ScreenLoading();
            }
          },
        ));
  }
}
